import React, { memo, useRef, useState, Fragment, forwardRef } from 'react';
import { useUpdateEffect } from '../../hooks';
import styled, { css } from 'styled-components';
import { AUTOSIZE_INPUT_ATTRS } from '../../constants';
const INPUT_MIN_WIDTH_PX = 15;
const INPUT_FONT_STYLE = css `
  font-size: inherit;
  font-weight: inherit;
  font-family: inherit;
`;
const SizerDiv = styled.div `
  top: 0;
  left: 0;
  height: 0;
  overflow: scroll;
  white-space: pre;
  position: absolute;
  visibility: hidden;
  ${INPUT_FONT_STYLE}
  ${({ theme }) => theme.input.css}
`;
const Input = styled.input.attrs(AUTOSIZE_INPUT_ATTRS) `
  border: 0;
  outline: 0;
  padding: 0;
  cursor: text;
  background: 0;
  color: inherit;
  box-sizing: content-box;
  ${INPUT_FONT_STYLE}

  :read-only {
    opacity: 0;
    cursor: default;
  }

  :required {
    ${({ theme, isInvalid }) => isInvalid && theme.input.cssRequired}
  }

  ${({ theme }) => theme.input.css}
`;
const AutosizeInput = memo(forwardRef(({ id, onBlur, onFocus, readOnly, required, onChange, ariaLabel, inputValue, ariaLabelledBy, hasSelectedOptions }, ref) => {
    const isInvalid = !!required && !hasSelectedOptions;
    const sizerRef = useRef(null);
    const [inputWidth, setInputWidth] = useState(INPUT_MIN_WIDTH_PX);
    useUpdateEffect(() => {
        const { current: el } = sizerRef;
        if (el) {
            setInputWidth(el.scrollWidth + INPUT_MIN_WIDTH_PX);
        }
    }, [inputValue]);
    return (React.createElement(Fragment, null,
        React.createElement(Input, { id: id, ref: ref, isInvalid: true, onBlur: onBlur, onFocus: onFocus, value: inputValue, readOnly: readOnly, required: isInvalid, "aria-label": ariaLabel, style: { width: inputWidth }, "aria-labelledby": ariaLabelledBy, onChange: !readOnly ? onChange : undefined }),
        React.createElement(SizerDiv, { ref: sizerRef }, inputValue)));
}));
AutosizeInput.displayName = 'AutosizeInput';
export default AutosizeInput;
