import React, { memo } from 'react';
import { areEqual } from 'react-window';
import { buildOptionClsName } from '../../utils';
// Custom comparison function for React.memo().
// Extends functionality provided from "areEqual" with added bailout feature based on value of "memoOptions"
const propsAreEqual = (prevProps, nextProps) => {
    const { memoOptions } = nextProps.data;
    return memoOptions && areEqual(prevProps, nextProps);
};
const Option = memo(({ index, style, data: { menuOptions, selectOption, renderOptionLabel, focusedOptionIndex } }) => {
    const { data, value, label, isDisabled, isSelected } = menuOptions[index];
    const className = buildOptionClsName(isDisabled, isSelected, (index === focusedOptionIndex));
    const onClick = !isDisabled ? () => selectOption({ data, value, label }, isSelected) : undefined;
    return (React.createElement("div", { style: style, onClick: onClick, className: className }, renderOptionLabel(data)));
}, propsAreEqual);
Option.displayName = 'Option';
export default Option;
