import { useEffect, useRef, useCallback } from 'react';
/**
 * A custom hook that converts a callback to a ref to avoid triggering re-renders
 * ..when passed as a prop or avoid re-executing effects when passed as a dependency
 *
 * @param callback The callback to write to a ref object
 */
const useCallbackRef = (callback) => {
    const callbackRef = useRef(callback);
    useEffect(() => {
        callbackRef.current = callback;
    });
    return useCallback(((...args) => {
        var _a;
        return (_a = callbackRef.current) === null || _a === void 0 ? void 0 : _a.call(callbackRef, ...args);
    }), []);
};
export default useCallbackRef;
