import { OPTION_CLS, EMPTY_ARRAY, OPTION_FOCUSED_CLS, OPTION_SELECTED_CLS, OPTION_DISABLED_CLS } from '../constants';
const STYLED_ANI_KEY = 'animation';
const DIACRITICS_REG_EXP = /[\u0300-\u036f]/g;
/**
 * @private
 *
 * Strips all diacritics from a string.
 * May not be supported by all legacy browsers (IE11 >=).
 */
const stripDiacritics = (val) => val.normalize('NFD').replace(DIACRITICS_REG_EXP, '');
// Simple helper functions
export const isBoolean = (val) => typeof val === 'boolean';
export const isFunction = (val) => typeof val === 'function';
export const isArrayWithLength = (val) => Array.isArray(val) && !!val.length;
export const isPlainObject = (val) => val !== null && typeof val === 'object' && !Array.isArray(val);
/**
 * Call preventDefault() and stopPropagation() on event.
 */
export const suppressEvent = (e) => {
    e.preventDefault();
    e.stopPropagation();
};
/**
 * Apply regex to string, and if the value is NOT case sensitive,
 * call .toLowerCase() and return result.
 */
export const trimAndFormatFilterStr = (value, filterIgnoreCase, filterIgnoreAccents) => {
    let trimVal = value.trim();
    if (filterIgnoreCase) {
        trimVal = trimVal.toLowerCase();
    }
    return !filterIgnoreAccents ? trimVal : stripDiacritics(trimVal);
};
/**
 * Builds the className property in Option.tsx component.
 */
export const buildOptionClsName = (isDisabled, isSelected, isFocused) => {
    let className = OPTION_CLS;
    if (isDisabled)
        className += ` ${OPTION_DISABLED_CLS}`;
    if (isSelected)
        className += ` ${OPTION_SELECTED_CLS}`;
    if (isFocused)
        className += ` ${OPTION_FOCUSED_CLS}`;
    return className;
};
/**
 * Parses an object or an array of objects into output of SelectedOption[].
 */
export const normalizeValue = (value, getOptionValue, getOptionLabel) => {
    const initValues = Array.isArray(value)
        ? value
        : isPlainObject(value)
            ? [value]
            : EMPTY_ARRAY;
    if (!isArrayWithLength(initValues)) {
        return initValues;
    }
    return initValues.map((data) => ({
        data,
        value: getOptionValue(data),
        label: getOptionLabel(data)
    }));
};
/**
 * Immutable implementation of mergeDeep for two objects. Will return the merged result.
 * In first condition of if/else block - check that property is no 'animation',
 * since we never want to merge that complex styled-component object.
 */
export const mergeDeep = (target, source) => {
    const output = { ...target };
    Object.keys(source).forEach((key) => {
        const sourceProp = source[key];
        output[key] =
            (key !== STYLED_ANI_KEY && isPlainObject(sourceProp))
                ? target[key]
                    ? mergeDeep(target[key], sourceProp)
                    : sourceProp
                : sourceProp !== null && sourceProp !== void 0 ? sourceProp : '';
    });
    return output;
};
